.. _contributing:

============
Contributing
============

orix is a community maintained project.
We welcome contributions in the form of bug reports, feature requests, code,
documentation, and more.
The source code is hosted `on GitHub <https://github.com/pyxem/orix>`__.
These guidelines provide resources on how best to contribute.

For contributors unfamiliar with GitHub, checking out the `GitHub guides
<https://guides.github.com>`__ are recommended.

.. tip::

    This guide can look intimidating to people who want to contribute, but have limited
    experience with tools like ``git``, ``pytest``, and ``sphinx``. The shortest route
    to start contributing is to create a GitHub account and explain what you want to do
    `in an issue <https://github.com/pyxem/orix/issues/new>`__.

    That said, our contributing workflow is typical for Python projects, so reading this
    guide can make contributing to similar projects in the future much smoother!

Have a question, comment, suggestion for improvements, or any other inquiries
regarding the project?
Feel free to `ask a question <https://github.com/pyxem/orix/discussions>`__,
`open an issue <https://github.com/pyxem/orix/issues>`__ or `make a pull request
<https://github.com/pyxem/orix/pulls>`__ in our GitHub repository.

.. toctree::
    :maxdepth: 1

    setting_up_development_installation.rst
    code_style.rst
    using_git.rst
    building_writing_documentation.rst
    handling_deprecations.rst
    running_writing_tests.rst
    adding_to_data_module.rst
    continuous_integration.rst